aboutsummaryrefslogtreecommitdiffstats
path: root/lib/diameter/test
diff options
context:
space:
mode:
authorAnders Svensson <[email protected]>2011-09-27 20:20:43 +0200
committerAnders Svensson <[email protected]>2011-09-27 20:20:43 +0200
commit58fe7b5e48ad95f14b05aae43a3a32122695da4e (patch)
treed4dbc0838f6053fd6ff9cc66c52f6a1b0fd5e36f /lib/diameter/test
parent5d61dc1014b17e417ddc13e220283745460af70c (diff)
parent0296dbb27b20c75edc6a2dd75369dc17dc98aa5a (diff)
downloadotp-58fe7b5e48ad95f14b05aae43a3a32122695da4e.tar.gz
otp-58fe7b5e48ad95f14b05aae43a3a32122695da4e.tar.bz2
otp-58fe7b5e48ad95f14b05aae43a3a32122695da4e.zip
Merge branch 'anders/diameter/release-0.10' into dev
* anders/diameter/release-0.10: Example/dbg/comment fixes Don't include compiler/help modules in app Set version to 0.10 and update appup
Diffstat (limited to 'lib/diameter/test')
-rw-r--r--lib/diameter/test/diameter_app_SUITE.erl12
-rw-r--r--lib/diameter/test/diameter_codec_SUITE.erl5
-rw-r--r--lib/diameter/test/diameter_relay_SUITE.erl2
3 files changed, 13 insertions, 6 deletions
diff --git a/lib/diameter/test/diameter_codec_SUITE.erl b/lib/diameter/test/diameter_codec_SUITE.erl
index 0c004b3edb..30c60be8e9 100644
--- a/lib/diameter/test/diameter_codec_SUITE.erl
+++ b/lib/diameter/test/diameter_codec_SUITE.erl
@@ -21,9 +21,8 @@
%% Test encode/decode of dictionary-related modules. Each test case
%% runs multiple tests in parallel since many of the tests are just
%% the same code with different in-data: implementing each test as a
-%% single testcase would make for much duplication with ct's
-%% requirement of one function per testcase. (Instead of allowing a
-%% testcase to be an MFA instead of function name, say.)
+%% single testcase would make for much duplication with ct's current
+%% requirement of one function per testcase.
%%
-module(diameter_codec_SUITE).
diff --git a/lib/diameter/test/diameter_relay_SUITE.erl b/lib/diameter/test/diameter_relay_SUITE.erl
index 0cda2df8ca..6b2fda7855 100644
--- a/lib/diameter/test/diameter_relay_SUITE.erl
+++ b/lib/diameter/test/diameter_relay_SUITE.erl
@@ -26,7 +26,7 @@
%% / |
%% CLIENT.REALM1 |
%% \ |
-%% ---- RELAY.REALM3 ---- SERVER2.REALM3
+%% ---- RELAY.REALM3 ---- SERVER1.REALM3
%% \
%% --- SERVER2.REALM3
%%
diff --git a/lib/diameter/test/diameter_app_SUITE.erl b/lib/diameter/test/diameter_app_SUITE.erl
index d710fa155d..104785b4e6 100644
--- a/lib/diameter/test/diameter_app_SUITE.erl
+++ b/lib/diameter/test/diameter_app_SUITE.erl
@@ -86,13 +86,21 @@ vsn(Config) ->
%% ===========================================================================
%% # modules/1
%%
%% Ensure that the app file module list match the installed beams.
%% ===========================================================================
modules(Config) ->
Mods = fetch(modules, fetch(app, Config)),
Installed = code_mods(),
- {[], []} = {Mods -- Installed, Installed -- Mods}.
+ Help = [diameter_callback,
+ diameter_codegen,
+ diameter_dbg,
+ diameter_exprecs,
+ diameter_info,
+ diameter_spec_scan,
+ diameter_spec_util],
+ {[], Help} = {Mods -- Installed, lists:sort(Installed -- Mods)}.
code_mods() ->
Dir = code:lib_dir(?APP, ebin),
@@ -86,13 +86,21 @@ vsn(Config) ->
%% # modules/1
%%
-%% Ensure that the app file module list match the installed beams.
+%% Ensure that the app file modules and installed modules differ by
+%% compiler/help modules.
%% ===========================================================================
modules(Config) ->